@@ -21,6 +21,7 @@ if getattr(dbus, 'version', (0,0,0)) >= (0,41,0):
     import dbus.glib
 
 import uri_opener
+from BbsType import bbs_type_other
 
 dbus_interface_name = "tk.tetteke.FukuiNoNamari"
 
@@ -32,3 +33,7 @@ class DBusFukuiNoNamariObject(dbus.service.Object):
     @dbus.service.method(dbus_interface_name)
     def open_uri(self, uri, update=False):
         uri_opener.open_uri(uri, update)
+
+    @dbus.service.method(dbus_interface_name)
+    def whitelist_reload(self):
+        bbs_type_other.whitelist_load()
